"""
Author: Görsel Analiz 
Website: (www.gorselanaliz.com)
Date: 12/12/2024
Description: Bu kod yüz tespiti ve mesafe ölçümü yapar. 
Python Version: 3.10.x
"""

import pyrealsense2 as rs 
import numpy as np
import cv2

face_cascade = cv2.CascadeClassifier('haarcascade_frontalface_default.xml')

pipe = rs.pipeline()
cfg  = rs.config()

cfg.enable_stream(rs.stream.color, 640,480, rs.format.bgr8, 30)
cfg.enable_stream(rs.stream.depth, 640,480, rs.format.z16, 30)

pipe.start(cfg)

while True:
    frame = pipe.wait_for_frames()
    depth_frame = frame.get_depth_frame()
    color_frame = frame.get_color_frame()

    depth_image = np.asanyarray(depth_frame.get_data())
    color_image = np.asanyarray(color_frame.get_data())
    depth_cm = cv2.applyColorMap(cv2.convertScaleAbs(depth_image,
                                     alpha = 0.5), cv2.COLORMAP_JET)

    gray_image = cv2.cvtColor(color_image, cv2.COLOR_BGR2GRAY)
    faces = face_cascade.detectMultiScale(gray_image, scaleFactor=1.1, 
                                          minNeighbors=7, minSize=(50, 50))
    
    for (x, y, w, h) in faces:
        cv2.rectangle(color_image, (x, y), (x+w, y+h), (0, 255, 0), 2)
        
        center_x = x + w // 2
        center_y = y + h // 2

        center = (center_x, center_y)
        cv2.circle(color_image, center, 4, (0, 255, 0))

        depth_value = depth_frame.get_distance(center_x, center_y)      
        print(f"Piksel ({x}, {y}) Mesafe: {depth_value:.2f} metre")

        text = f"Mesafe: {depth_value:.2f} m"
        cv2.putText(color_image, text, (10, 30), cv2.FONT_HERSHEY_SIMPLEX, fontScale=1, color=(0, 255, 0), thickness=2)


    cv2.imshow('rgb', color_image)
    cv2.imshow('depth', depth_cm)

    if cv2.waitKey(1) == ord('q'):
        break

pipe.stop()