"""
Author: Görsel Analiz 
Website: (www.gorselanaliz.com)
Date: 12/12/2024
Description: Bu kod yüz tespiti ve mesafe ölçümü yapar. 
Python Version: 3.10.x
"""

import pyrealsense2 as rs 
import numpy as np
import cv2

pipe = rs.pipeline()
cfg  = rs.config()

cfg.enable_stream(rs.stream.color, 640,480, rs.format.bgr8, 30)
cfg.enable_stream(rs.stream.depth, 640,480, rs.format.z16, 30)

pipe.start(cfg)

while True:
    frame = pipe.wait_for_frames()
    depth_frame = frame.get_depth_frame()
    color_frame = frame.get_color_frame()

    if not depth_frame:
        continue

    depth_image = np.asanyarray(depth_frame.get_data())
    color_image = np.asanyarray(color_frame.get_data())
    depth_cm = cv2.applyColorMap(cv2.convertScaleAbs(depth_image,
                                     alpha = 0.5), cv2.COLORMAP_JET)

    x, y = 320, 240  
    cv2.circle(color_image, (x, y), 4, (0, 0, 255))

    depth_value = depth_frame.get_distance(x, y)      
    print(f"Pixel ({x}, {y}) depth: {depth_value:.2f} metre")
    
    cv2.imshow('rgb', color_image)
    cv2.imshow('depth', depth_cm)

    if cv2.waitKey(1) == ord('q'):
        break

pipe.stop()